@@ -1,4 +1,4 @@
-test_that("match_fips", {
+test_that('match_fips', {
   a <- match_fips('NY')
   b <- match_fips('36')
   c <- match_fips('New York')
@@ -10,7 +10,7 @@ test_that("match_fips", {
   expect_equal(d, '36')
 })
 
-test_that("match_abb", {
+test_that('match_abb', {
   a <- match_abb('NY')
   b <- match_abb('36')
   c <- match_abb('New York')
@@ -22,7 +22,7 @@ test_that("match_abb", {
   expect_equal(d, 'NY')
 })
 
-test_that("match_name", {
+test_that('match_name', {
   a <- match_name('NY')
   b <- match_name('36')
   c <- match_name('New York')
@@ -34,7 +34,7 @@ test_that("match_name", {
   expect_equal(d, 'New York')
 })
 
-test_that("match_ansi", {
+test_that('match_ansi', {
   a <- match_ansi('NY')
   b <- match_ansi('36')
   c <- match_ansi('New York')
